# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

### Added
- New features and improvements coming in the next release

### Changed
- Changes in existing functionality

### Deprecated
- Features that will be removed in upcoming releases

### Removed
- Features that have been removed

### Fixed
- Bug fixes

### Security
- Security vulnerability fixes

---

## [1.3.16] - 2025-07-24

Stable release before restructure the project to support  variou input and output formats

---

## Version History

- **1.3.16** - Stable release before restructure the project to support  variou input and output formats (2025-07-24)

---

## Contributing

When contributing to this project, please update this changelog by adding a new entry under the [Unreleased] section. Follow the format described in [Keep a Changelog](https://keepachangelog.com/en/1.0.0/).

### Changelog Entry Format

```markdown
## [Version] - YYYY-MM-DD

### Added
- New features

### Changed
- Changes in existing functionality

### Deprecated
- Features that will be removed

### Removed
- Removed features

### Fixed
- Bug fixes

### Security
- Security fixes
```

---

## Links

- [GitHub Repository](https://github.com/thangqd/vgrid)
- [PyPI Package](https://pypi.org/project/vgrid/)
- [Documentation](https://vgrid.vn)
- [Issues](https://github.com/thangqd/vgrid/issues)
- [Releases](https://github.com/thangqd/vgrid/releases)
